if not SimpleTankFrames then return end
local addon = SimpleTankFrames

local frame = CreateFrame("Frame", nil, InterfaceOptionsFramePanelContainer)
frame.name = "SimpleTankFrames"
frame:Hide()

local L = LibStub("AceLocale-3.0"):GetLocale("SimpleTankFrames")

local function newCheckbox(label, onClick)
	local check = CreateFrame("CheckButton", "SimpleTankFrameCheck" .. label, frame, "InterfaceOptionsCheckButtonTemplate")
	check:SetScript("OnClick", function(self)
		PlaySound(self:GetChecked() and "igMainMenuOptionCheckBoxOn" or "igMainMenuOptionCheckBoxOff")
		onClick(self, self:GetChecked() and true or false)
	end)
	_G[check:GetName() .. "Text"]:SetText(label)
	return check
end

local checkboxFunc = function(self, value) addon.db[self.key] = value end

local function round(num, dec)
	local m = 10^(dec or 0)
	return math.floor(num * m + 0.5) / m
end
frame:SetScript("OnShow", function(frame)
	local title = frame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText("SimpleTankFrames")

	local subTitleWrapper = CreateFrame("Frame", nil, frame)
	subTitleWrapper:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subTitleWrapper:SetPoint("RIGHT", -32, 0)
	local subtitle = subTitleWrapper:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmall")
	subtitle:SetPoint("TOPLEFT", subTitleWrapper)
	subtitle:SetWidth(subTitleWrapper:GetRight() - subTitleWrapper:GetLeft())
	subtitle:SetJustifyH("LEFT")
	subtitle:SetNonSpaceWrap(false)
	subtitle:SetJustifyV("TOP")
	subtitle:SetText(L["oRA2-style main tank frames populated by the sorted tank list from oRA3. |cffff4411Note that NONE of these settings apply until you reload your interface or relog.|r"])
	subTitleWrapper:SetHeight(subtitle:GetHeight())

	local lock = newCheckbox(L["Lock"], checkboxFunc)
	lock.key = "lock"
	lock:SetChecked(addon.db.lock)
	lock:SetPoint("TOPLEFT", subTitleWrapper, "BOTTOMLEFT", -2, -8)

	local percent = newCheckbox(L["Hitpoints"], checkboxFunc)
	percent.key = "showHp"
	percent:SetChecked(addon.db.showHp)
	percent:SetPoint("TOPLEFT", lock, "BOTTOMLEFT", 0, -8)

	local highlight = newCheckbox(L["Target highlight"], checkboxFunc)
	highlight.key = "highlight"
	highlight:SetChecked(addon.db.highlight)
	highlight:SetPoint("TOPLEFT", subtitle, "BOTTOMRIGHT", -160, -8)

	local tot = newCheckbox(L["Target of target"], checkboxFunc)
	tot.key = "tot"
	tot:SetChecked(addon.db.tot)
	tot:SetPoint("TOPLEFT", highlight, "BOTTOMLEFT", 0, -8)

	local growup = newCheckbox(L["Grow upwards"], checkboxFunc)
	growup.key = "growup"
	growup:SetChecked(addon.db.growup)
	growup:SetPoint("TOPLEFT", percent, "BOTTOMLEFT", 0, -8)

	local media = LibStub and LibStub("LibSharedMedia-3.0", true)
	local texture = nil
	if media then
		texture = frame:CreateFontString(nil, "OVERLAY", "GameFontNormal")
		texture:SetPoint("TOPLEFT", growup, "BOTTOMLEFT", 8, -24)
		texture:SetJustifyH("LEFT")
		texture:SetHeight(18)
		texture:SetText("Texture")
		local dropdown = CreateFrame("Frame", "SimpleTankFrameTextureDropdown", frame, "UIDropDownMenuTemplate")
		dropdown:SetPoint("TOPLEFT", texture, "TOPRIGHT", 16, 3)
		local function itemOnClick(self)
			local selected = self.value
			local actualTexture = media:Fetch("statusbar", selected)
			addon.db.bar = actualTexture
			UIDropDownMenu_SetSelectedValue(dropdown, selected)
		end
		UIDropDownMenu_Initialize(dropdown, function()
			local info = UIDropDownMenu_CreateInfo()
			for name, tex in pairs(media:HashTable("statusbar")) do
				info.text = name
				info.value = name
				info.func = itemOnClick
				info.checked = tex == addon.db.bar
				UIDropDownMenu_AddButton(info)
			end
		end)
		UIDropDownMenu_SetSelectedValue(dropdown, addon.db.bar)
		UIDropDownMenu_SetWidth(dropdown, 160)
		UIDropDownMenu_JustifyText(dropdown, "LEFT")
	end

	local scaleLabel = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	scaleLabel:SetJustifyH("LEFT")
	scaleLabel:SetText(L["Scale"])
	scaleLabel:SetPoint("TOPLEFT", texture or growup, "BOTTOMLEFT", 8, -28)

	local scale = CreateFrame("Slider", "STIScaleSlider", frame, "OptionsSliderTemplate")
	local scaleValue = _G.STIScaleSliderText
	scaleValue:SetText(addon.db.scale)
	scale:SetHeight(17)
	scale:SetWidth(175)
	scale:SetMinMaxValues(0.05, 2.15)
	scale:SetValue(addon.db.scale)
	scale:SetValueStep(.05)
	scale:SetScript("OnValueChanged", function(self, value)
		local v = round(value, 2)
		addon.db.scale = v
		scaleValue:SetText(v)
	end)
	scale:SetPoint("LEFT", scaleLabel, "RIGHT", 38, 0)

	local alphaLabel = frame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	alphaLabel:SetJustifyH("LEFT")
	alphaLabel:SetText(L["Alpha"])
	alphaLabel:SetPoint("TOPLEFT", scaleLabel, "BOTTOMLEFT", 0, -28)

	local alpha = CreateFrame("Slider", "STIAlphaSlider", frame, "OptionsSliderTemplate")
	local alphaValue = _G.STIAlphaSliderText
	alphaValue:SetText(addon.db.alpha)
	alpha:SetHeight(17)
	alpha:SetWidth(175)
	alpha:SetMinMaxValues(0.1, 1)
	alpha:SetValue(addon.db.alpha)
	alpha:SetValueStep(0.1)
	alpha:SetScript("OnValueChanged", function(self, value)
		local v = round(value, 1)
		addon.db.alpha = v
		alphaValue:SetText(v)
	end)
	alpha:SetPoint("LEFT", alphaLabel, "RIGHT", 38, 0)

	frame:SetScript("OnShow", nil)
end)
InterfaceOptions_AddCategory(frame)

